@@ -17,11 +17,15 @@ BEGIN
     use warnings;
     use warnings::register;
     use parent qw( Module::Generic );
+    use vars qw( $VERSION );
     use Regexp::Common qw( Apache2 );
     use PPI;
     our $VERSION = 'v0.1.0';
 };
 
+use strict;
+use warnings;
+
 sub init
 {
     my $self = shift( @_ );
@@ -49,11 +53,9 @@ sub parse
     }
     pos( $data ) = 0;
     my $prefix = $self->legacy ? 'Legacy' : $self->trunk ? 'Trunk' : '';
-    $self->message( 3, "Using prefix '$prefix'." );
     my @callinfo = caller(0);
     $opts->{top} = 0;
     $opts->{top} = 1 if( $callinfo[0] ne ref( $self ) || ( $callinfo[0] eq ref( $self ) && substr( (caller(1))[3], rindex( (caller(1))[3], ':' ) + 1 ) ne 'parse' ) );
-    $self->message( 3, "Parsing expression '$data'. Called from file $callinfo[1] at line $callinfo[2] and from sub ", (caller(1))[3], ". top is set to '$opts->{top}'" );
     ## This is used to avoid looping when an expression drills down its substring by calling parse again
     my $skip = {};
     if( ref( $opts->{skip} ) eq 'ARRAY' &&
@@ -61,7 +63,6 @@ sub parse
     {
         @$skip{ @{$opts->{skip}} } = ( 1 ) x scalar( @{$opts->{skip}} )
     }
-    $self->message( 3, "Skip contains: ", sub{ $self->dump( $skip ) });
     my $p = {};
     $p->{is_negative} = 0;
     my $elems = [];
@@ -74,11 +75,8 @@ sub parse
     PARSE:
     {
         my $pos = pos( $data );
-        $self->message( 3, "Nothing more to parse at pos '$pos'. End of data." ), last PARSE if( pos( $data ) == length( $data ) );
-        $self->message( 3, "Parsing ", length( $data ), " bytes of data starting at '$pos' in string '$data'" );
         if( $data =~ m/\G\r?\n$/ )
         {
-            $self->message( 3, "End of string new line detected, skipping." );
             redo PARSE;
         }
         elsif( $self->message( 3, "Trying with legacy variable." ) && 
@@ -86,9 +84,7 @@ sub parse
                length( $+{variable} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in legacy variable." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "variable => capture groups for $+{variable} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements => [],
@@ -132,9 +128,7 @@ sub parse
                length( $+{cond} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in condition." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "condition => capture groups for '$+{cond}' in data '$data' are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements => [],
@@ -221,9 +215,7 @@ sub parse
                length( $+{stringcomp} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in string comp." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "stringcomp => capture groups for $+{stringcomp} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -256,9 +248,7 @@ sub parse
                length( $+{integercomp} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in integer comp." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "integercomp => capture groups for $+{integercomp} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -300,9 +290,7 @@ sub parse
 #         {
             my $re = { %+ };
             my $cur_pos = pos( $data );
-            $self->message( 3, "Got here in comp." );
             $self->whereami( \$data, $cur_pos );
-            $self->message( 3, "comparison => capture groups for $+{comp} are: ", sub{ $self->dump( $re ) });
             ## next PARSE unless( length( $re->{comp} ) );
             my $def =
             {
@@ -315,7 +303,6 @@ sub parse
             my $chunk = $re->{comp};
             if( length( $re->{comp_unary} ) )
             {
-                $self->message( 3, "Found unary operation." );
                 $def->{subtype} = 'unary';
                 $def->{op} = $re->{comp_unaryop};
                 $def->{word} = $re->{comp_word};
@@ -329,7 +316,6 @@ sub parse
             }
             elsif( length( $re->{comp_binary} ) )
             {
-                $self->message( 3, "Found binary operation." );
                 $def->{subtype} = 'binary';
                 $def->{op}      = $re->{comp_binaryop};
                 $def->{is_negative} = ( defined( $re->{comp_binary_is_neg} ) ? length( $re->{comp_binary_is_neg} ) > 0 ? 1 : 0 : 0 );
@@ -352,7 +338,6 @@ sub parse
             }
             elsif( length( $re->{comp_word_in_listfunc} ) )
             {
-                $self->message( 3, "Found function." );
                 $def->{subtype} = 'function';
                 $def->{word}    = $re->{comp_word};
                 $def->{function}    = $re->{comp_listfunc};
@@ -370,7 +355,6 @@ sub parse
             }
             elsif( length( $re->{comp_in_regexp} ) || length( $re->{comp_in_regexp_legacy} ) )
             {
-                $self->message( 3, "Found regular expression." );
                 $def->{subtype} = 'regexp';
                 $def->{word}    = $re->{comp_word};
                 $def->{op}      = $re->{comp_regexp_op};
@@ -394,7 +378,6 @@ sub parse
             }
             elsif( length( $re->{comp_word_in_list} ) )
             {
-                $self->message( 3, "Found comparison to list." );
                 $def->{subtype} = 'list';
                 $def->{word}    = $re->{comp_word};
                 $def->{list}    = $re->{com_list};
@@ -419,7 +402,6 @@ sub parse
             }
             else
             {
-                $self->message( 3, "No match found in comparison." );
             }
             if( defined( $this ) && scalar( keys( %$this ) ) )
             {
@@ -437,9 +419,7 @@ sub parse
                length( $+{join} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in join for string '$data'." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "join => capture groups for $+{join} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -476,9 +456,7 @@ sub parse
                length( $+{split} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in split for string '$data'." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "split => capture groups for $+{split} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -516,9 +494,7 @@ sub parse
                length( $+{sub} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in sub for string '$data'." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "sub => capture groups for $+{split} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -548,9 +524,7 @@ sub parse
                length( $+{function} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in function for string '$data'." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "function => capture groups for $+{function} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -579,9 +553,7 @@ sub parse
                length( $+{listfunc} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in listfunc." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "listfunc => capture groups for $+{listfunc} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements => [],
@@ -610,9 +582,7 @@ sub parse
                length( $+{regex} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in regex." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "regex => capture groups for $+{regex} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -633,9 +603,7 @@ sub parse
                length( $+{regany} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in regany." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "regany => capture groups for $+{regany} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -655,9 +623,7 @@ sub parse
                length( $+{regsub} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in regsub." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "regsub => capture groups for $+{regsub} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements    => [],
@@ -678,9 +644,7 @@ sub parse
                length( $+{words} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in words." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "words => capture groups for $+{words} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements => [],
@@ -697,7 +661,6 @@ sub parse
                 $def->{elements} = $this2->{elements};
                 $def->{list_def} = $this2->{elements};
                 $def->{words_def} = [];
-                $self->message( "Found list word '$def->{word}' with sublist '$def->{sublist}'" );
                 my $this = $self->parse( $def->{word}, skip => [qw( words )] );
                 push( @{$def->{words_def}}, @{$this->{elements}} );
                 
@@ -707,7 +670,6 @@ sub parse
                     my $re2 = { %+ };
                     $re2->{words_word} = '' if( !exists( $re2->{words_word} ) );
                     $re2->{words_sublist} = '' if( !exists( $re2->{words_sublist} ) );
-                    $self->message( "Found list word '$re2->{words_word}' with sublist '$re2->{words_sublist}" );
                     my $this = $self->parse( $re2->{words_word}, skip => [qw( words )] );
                     push( @{$def->{words_def}}, @{$this->{elements}} );
                     $tmp = $re2->{words_sublist} if( $re2->{words_sublist} );
@@ -729,9 +691,7 @@ sub parse
                length( $+{word} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in word." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "word => capture groups for '$+{word}' are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements => [],
@@ -768,7 +728,7 @@ sub parse
                     push( @{$def->{elements}}, @{$this->{elements}} );
                     $def->{word_def} = $this->{elements};
                 }
-                # XXX Should probably make a run on the enclosed word as it could be a variable
+                # NOTE: Should probably make a run on the enclosed word as it could be a variable
                 # For example: "Go back to %{REQUEST_URI}"
             }
             elsif( length( $re->{word_function} ) || length( $re->{word_variable} ) )
@@ -835,9 +795,7 @@ sub parse
                length( $+{string} ) )
         {
             my $re = { %+ };
-            $self->message( 3, "Got here in string." );
             $self->whereami( \$data, pos( $data ) );
-            $self->message( 3, "string => capture groups for $+{string} are: ", sub{ $self->dump( $re ) });
             my $def =
             {
             elements => [],
@@ -850,10 +808,7 @@ sub parse
         }
         else
         {
-            $self->message( 3, "Do not know what to do with '$data'." );
         }
-        $self->message( 3, "Nothing found." );
-        $self->message( 3, "Looping detected now exiting parsing." ) && last PARSE if( ++$looping > 1 );
         ## We arrived here, which means we could not find anything suitable in our parser, instead of returning a result for part of the data parsed, we return the original string marking it as nomatch string.
         if( $opts->{top} )
         {
@@ -864,11 +819,9 @@ sub parse
             raw => $data,
             pos => $pos,
             });
-            $self->message( 3, "Failed to complete parsing, so returning original data as string: ", sub{ $self->dump( $elems ) } );
             last PARSE;
         }
     };
-    $self->message( 3, "Returning hash: ", sub{ $self->dump( $hash ) } );
     return( scalar( @$elems ) ? $hash : {} );
 }
 
@@ -877,13 +830,11 @@ sub parse_args
     my $self = shift( @_ );
     ## String
     my $args = shift( @_ );
-    $self->message( 3, "Parsing arguments: '$args'." );
     my $doc = PPI::Document->new( \$args, readonly => 1 ) || 
         return( "Unable to parse: ", PPI::Document->errstr, "\n$args" );
     ## Nothing found as argument
     return( () ) if( !scalar( @{$doc->{children}} ) );
     return( $self->error( "Was expecting a statement, but got ", ($doc->elements)[0]->class ) ) if( ($doc->elements)[0]->class ne 'PPI::Statement' );
-    $self->message( 3, "Arguments contains the following PPI structure: ", sub{ $self->dump( $doc->{children} ) });
     my $st = ($doc->elements)[0];
     my @children = $st->elements;
     my $op_skip = 
@@ -891,7 +842,8 @@ sub parse_args
     ',' => 1,
     };
     my $expect = 0;
-    local $recur = sub
+    my $recur;
+    $recur = sub
     {
         my @elems = @_;
         ## We need space, so we do not remove them
@@ -923,10 +875,9 @@ sub parse_args
             }
             elsif( $e->class eq 'PPI::Token::Operator' && $e->content eq ',' )
             {
-                $self->message( 3, "Found a comma separating argument '", ( ( $i - 1 ) >= 0 ? $elems[$i-1]->content : '' ), "' and '", ( ( $i + 1 ) <= scalar( @elems ) ? $elems[$i+1]->content : '' ), "'." );
             }
             ## Either this is arguments for the previous function found, or this is expressions embedded within parenthesis
-            # XXX Need to implement also PPI::Token::Structure, i.e. [], {}
+            # NOTE: Need to implement also PPI::Token::Structure, i.e. [], {}
             elsif( $e->class eq 'PPI::Structure::List' )
             {
                 if( ref( $elems[$i - 1] ) && 
@@ -950,13 +901,11 @@ sub parse_args
             ## else we are not interested
             else
             {
-                $self->message( 3, "Clueless about what I should do with element of class '", $e->class, "' and value '", $e->content, "'." );
             }
         }
         return( @$argv );
     };
     my @objects = $recur->( @children );
-    $self->message( 3, "Objects found: ", sub{ $self->dump( @objects ) } );
     ## Stringify result
     my @result = map( join( '', map( $_->content, @$_ ) ), @objects );
     return( @result );
@@ -977,7 +926,6 @@ sub whereami
     $lookback += () = substr( $$ref, $start, $lookback ) =~ /\n/gs;
     $first_line =~ s/\n/\\n/gs;
     my $sec_line = ( '.' x $lookback ) . '^' . ( '.' x $lookahead );
-    $self->message( 3, "Cusrsor is now here at position '$pos':\n$first_line\n$sec_line" );
 }
 
 ## PPI object manipulation
