@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Apache2 Server Side Include Parser - ~/lib/Apache2/SSI/File/Type.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/03/27
-## Modified 2021/03/29
+## Modified 2022/10/21
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -17,15 +17,17 @@ BEGIN
     use warnings;
     use warnings::register;
     use parent qw( Module::Generic );
+    use vars qw( $VERSION $TEMPLATES $ESC $MAGIC_DATA $MAGIC_DATA_SOURCE );
     use Digest::MD5;
     use File::Basename ();
     use File::Spec ();
     use IO::File;
+    use JSON;
     use Nice::Try;
     use Scalar::Util ();
     use URI::file;
-    our $VERSION = 'v0.1.0';
-    ## Translation of type in magic file to unpack template and byte count
+    our $VERSION = 'v0.1.1';
+    # Translation of type in magic file to unpack template and byte count
     our $TEMPLATES = 
     {
     'byte'      => [ 'c', 1 ],
@@ -50,7 +52,7 @@ BEGIN
     'string'    => undef(),
     };
     
-    ## For letter escapes in magic file
+    # For letter escapes in magic file
     our $ESC = 
     {
     'n' => "\n",
@@ -59,12 +61,15 @@ BEGIN
     't' => "\t",
     'f' => "\f"
     };
-    ## Cache
+    # Cache
     our $MAGIC_DATA = [];
-    ## Keep a record of the source data file, if any, so we can re-use this cached data instead of re-reading from it
+    # Keep a record of the source data file, if any, so we can re-use this cached data instead of re-reading from it
     our $MAGIC_DATA_SOURCE = '';
 };
 
+use strict;
+use warnings;
+
 sub init
 {
     my $self = shift( @_ );
@@ -74,15 +79,15 @@ sub init
     $opts->{magic} = $file if( length( $file ) );
     $self->{follow_links} = 1;
     $self->{check_magic}  = 0;
-    ## If there is an error or file is empty, it returns undef instead of application/octet-stream
+    # If there is an error or file is empty, it returns undef instead of application/octet-stream
     $self->{error_returns_undef} = 0;
-    ## Default to returns text/plain. If not, it will return an empty string and leave the caller to set the default mime-type.
+    # Default to returns text/plain. If not, it will return an empty string and leave the caller to set the default mime-type.
     $self->{default_type} = 'text/plain';
     $self->{_init_strict_use_sub} = 1;
     $self->SUPER::init( @_ );
     $self->{magic}        = {};
     $self->{magic_data}   = [];
-    local $load_json_data = sub
+    my $load_json_data = sub
     {
         my $json_file = shift( @_ ) || return;
         my $io = IO::File->new( "<$json_file" ) ||
@@ -106,10 +111,8 @@ sub init
     {
         $file = $opts->{magic};
         my $file_abs = URI::file->new_abs( $file )->file( $^O );
-        $self->message( 3, "Magic file \"$file\" ($file_abs) provided. slurping it." );
         if( $file_abs eq $MAGIC_DATA_SOURCE && scalar( @$MAGIC_DATA ) )
         {
-            $self->message( 3, "Data for magic file \"$file\" ($file_abs) is already loaded, re-using it." );
             $self->{magic_data} = $MAGIC_DATA;
         }
         else
@@ -119,7 +122,6 @@ sub init
             my $path = File::Spec->catpath( File::Spec->tmpdir, $base . "_${checksum}.json" );
             if( -e( $path ) && -s( $path ) )
             {
-                $self->message( 3, "Found previous magic json data file \"$path\", loading it instead." );
                 $load_json_data->( $path ) || return;
             }
             else
@@ -131,7 +133,6 @@ sub init
                 $self->parse_magic_file( $io );
                 $MAGIC_DATA = $self->{magic_data};
                 $io->close;
-                $self->message( 3, "Saving magic data to json cache file \"$path\"." );
                 my $json = $self->as_json || return;
                 my $fh = IO::File->new( ">$path" ) || 
                     return( $self->error( "Unable to write to magic cache json data file \"$path\": $!" ) );
@@ -150,7 +151,6 @@ sub init
     {
         $file = __FILE__;
         $file =~ s/\.pm/\.json/;
-        $self->message( 3, "No magic file specified, reading our magic json data from \"$file\"" );
         return( $self->error( "Apache2::SSI magic file \"$file\" does not exist." ) ) if( !-e( $file ) );
         $load_json_data->( $file ) || return;
     }
@@ -233,7 +233,7 @@ sub check
     my $data = [];
     while( !$io->eof() )
     {
-    	$self->read_magic_entry( $data );
+        $self->read_magic_entry( $data );
     }
     $io->close();
     $self->dump( $data );
@@ -285,7 +285,6 @@ sub dump
     $err->fdopen( fileno( STDERR ), 'w' ) || return( $self->error( "Cannot write to STDERR: $!" ) );
     $err->binmode;
 
-    $self->messagef( 3, "There are %d entries in \$data", scalar( @$data ) );
     foreach my $entry ( @$data )
     {
         ## Delayed evaluation.
@@ -326,7 +325,10 @@ sub error_returns_undef { return( shift->_set_get_boolean( 'error_returns_undef'
 sub file 
 {
     my $self = shift( @_ );
-    ## Iterate over each file explicitly so we can seek
+    # The description line. append info to this string
+    my $desc = '';
+    my $type = '';
+    # Iterate over each file explicitly so we can seek
     my $file = shift( @_ ) || do
     {
         if( $self->{error_returns_undef} )
@@ -339,13 +341,10 @@ sub file
             return( "x-system/x-error; $desc" );
         }
     };
-    ## The description line. append info to this string
-    my $desc = '';
-    my $type = '';
     
-    ## No need to let everybody know what is our server file system
+    # No need to let everybody know what is our server file system
     my $base_file = File::Basename::basename( $file );
-    ## 0) Check existence
+    # 0) Check existence
     if( !-e( $file ) )
     {
         if( $self->{error_returns_undef} )
@@ -358,7 +357,7 @@ sub file
             return( "x-system/x-error; $desc" );
         }
     }
-    ## 1) Check permission
+    # 1) Check permission
     elsif( !-r( $file ) ) 
     {
         if( $self->{error_returns_undef} )
@@ -372,7 +371,7 @@ sub file
         }
     }
     
-    ## 2) Check for various special files first
+    # 2) Check for various special files first
     if( $self->follow_links ) 
     {
         CORE::stat( $file ); 
@@ -381,7 +380,7 @@ sub file
     {
         CORE::lstat( $file );
     }
-    ## Avoid doing many useless redondant system stat, use '_'. See perlfunc man page
+    # Avoid doing many useless redondant system stat, use '_'. See perlfunc man page
     if( !-f( _ ) || -z( _ ) ) 
     {
         if( !$self->follow_links && -l( _ ) ) 
@@ -390,12 +389,12 @@ sub file
             return( 'application/x-link' );
         }
         elsif( -d( _ ) ) { return( 'application/x-directory' ); }
-        ## Named pipe
+        # Named pipe
         elsif( -p( _ ) ) { return( 'application/x-pipe' ); }
         elsif( -S( _ ) ) { return( 'application/x-socket' ); }
-        ## Block special file
+        # Block special file
         elsif( -b( _ ) ) { return( 'application/x-block' ); }
-        ## Character special file
+        # Character special file
         elsif( -c( _ ) ) { return( 'application/x-character' ); }
         elsif( -z( _ ) ) { return( 'application/x-empty' ); }
         else 
@@ -404,8 +403,7 @@ sub file
         }
     }
     
-    ## Current file handle. or undef if check_magic (-c option) is true.
-    $self->message( 3, "Opening file \"$file\" to have a peek." );
+    # Current file handle. or undef if check_magic (-c option) is true.
     my $io;
     $io = IO::File->new( "<$file" ) || do
     {
@@ -420,28 +418,26 @@ sub file
     };
     $io->binmode;
     
-    ## 3) Check for script
-    ## if( ( -x( $file ) || ( $^O =~ /^(dos|mswin32|NetWare|symbian|win32)$/i && $file =~ /\.(?:pl|cgi)$/ ) ) && 
+    # 3) Check for script
+    # if( ( -x( $file ) || ( $^O =~ /^(dos|mswin32|NetWare|symbian|win32)$/i && $file =~ /\.(?:pl|cgi)$/ ) ) && 
 #     if( ( -x( $file ) || $file =~ /\.(?:cgi|pl|t)$/ ) && 
 #         -T( _ ) ) 
     my $default;
     if( -x( $file ) && -T( _ ) ) 
     {
-        ## Note, some magic files include elaborate attempts to match #! header lines 
-        ## and return pretty responses but this slows down matching and is unnecessary.
+        # Note, some magic files include elaborate attempts to match #! header lines 
+        # and return pretty responses but this slows down matching and is unnecessary.
         my $line1 = $io->getline;
         if( $line1 =~ /^\#![[:blank:]\h]*(\S+)/ ) 
         {
-            ## Returns the binary name, without file path
+            # Returns the binary name, without file path
             my $bin_name = File::Basename::basename( $1 );
             #$desc .= " executable $bin_name script text";
-            ## $io->close;
-            ## return( "text/x-${bin_name}" );
+            # $io->close;
+            # return( "text/x-${bin_name}" );
             $default = "text/x-${bin_name}";
         }
     }
-    $self->message( 3, "Using file data to find content-type for file '$file'." );
-    ## $self->messagef( 3, "There are %d entries in \$self->{magic_data}", scalar( @{$self->{magic_data}} ) );
     my $out = $self->handle( $io, $desc, { default => $default } );
     $io->close;
     return( $out );
@@ -458,19 +454,15 @@ sub handle
     $opts->{default} = $self->default_type if( !length( $opts->{default} ) );
     my $type = '';
     
-    ## $self->message( 5, "Is file handle '$io' active ? ", ( Scalar::Util::blessed( $io ) && $io->opened ) ? 'Yes' : 'No' );
     ## 3) Iterate over each magic entry.
     my $match_found = 0;
-    ## $self->messagef( 3, "\$self->{magic_data} contains %d entries.", scalar( @{$self->{magic_data}} ) );
     for( my $m = 0; $m <= $#{ $self->{magic_data} }; $m++ ) 
     {
         ## Check if the m-th magic entry matches and if it does, then $desc will contain 
         ## an updated description
-        ## $self->message( 5, "Checking entry $m: (", scalar( @{$self->{magic_data}->[$m]} ), " elements)" ) if( scalar( @{$self->{magic_data}->[$m]} ) );
         my $test;
         if( ( $test = $self->_magic_match( $self->{magic_data}->[$m], \$desc, $io ) ) ) 
         {
-            ## $self->message( 4, "Found entry at position '$m'\n" );
             if( defined( $desc ) && $desc ne '' ) 
             {
                 $match_found = 1;
@@ -491,7 +483,6 @@ sub handle
             !$self->{magic}->{io}->eof )
         {
             $self->read_magic_entry();
-            #$self->message( 4, "\$self->{magic_data} is now %d items big.\n", scalar( @{$self->{magic_data}} ) );
         }
     }
     
@@ -732,7 +723,6 @@ sub read_magic_entry
         $line = '' if( !defined( $line ) );
         if( $line =~ /^\#/ || $line =~ /^[[:blank:]\h]*$/ ) 
         {
-            #$self->message( 4, "Line is a comment or is empty." );
             last if( $io->eof );
             $line = <$io>;
             $magic->{count}++;
@@ -743,7 +733,6 @@ sub read_magic_entry
         $this_depth    = '' if( !defined( $this_depth ) );
         $depth         = 0 if( !defined( $depth ) );
     
-        $self->message( 4, "\$this_depth ($this_depth), \$depth ($depth)" );
         if( length( $this_depth ) > $depth ) 
         {
             $magic->{buffer} = $line;
@@ -753,7 +742,6 @@ sub read_magic_entry
             if( $self->read_magic_entry( $entry->[2], $depth + 1 ) < $depth || 
                 $io->eof )
             {
-                $self->message( 4, "\$this_depth is greater than \$depth. Returning nothing" );
                 return;
             }
             $line = $magic->{buffer};
@@ -761,12 +749,10 @@ sub read_magic_entry
         elsif( length( $this_depth ) < $depth ) 
         {
             $magic->{buffer} = $line;
-            $self->message( 4, "\$this_depth is less than \$depth. Returning length( \$this_depth )" );
             return( length( $this_depth ) );
         }
         elsif( @$entry ) 
         {
-            $self->message( 4, "\@\$entry is defined. Returning length( \$this_depth )" );
             ## Already have an entry. This is not a continuation. Save this line for the 
             ## next call and exit.
             $magic->{buffer} = $line;
@@ -774,7 +760,6 @@ sub read_magic_entry
         }
         else 
         {
-            $self->message( 4, "Other: Setting \$entry and adding it to \@\$data. Ending loop (possibly). Fetching line" );
             ## We're here if the number of '>' is the same as the current depth and we 
             ## haven't read a magic line yet.
 
@@ -786,12 +771,10 @@ sub read_magic_entry
             push( @$data, $entry );
 
             ## Read the next line
-            $self->message( 4, "We reached end of file $io->eof()\n" ) if( $io->eof() );
             last if( $io->eof() );
             $line = <$io>;
             my $tmp = $line;
             $tmp =~ s/\n$//gs;
-            $self->message( 4, "(2) Fetched line '$tmp'\n" );
             $magic->{count}++;
         }
         ## print( STDERR "$line" );
@@ -933,18 +916,13 @@ sub _magic_match
     ## allows reading/checking the entire magic file.
     return( $self->error( "File handle is not defined." ) ) unless( defined( $io ) );
     ## return unless( defined( fileno( $io ) ) );
-    # $self->message( 3, "Is file handle '$io' active ? (", Scalar::Util::openhandle( $io ) ? 'yes' : 'no', ")." );
     # return unless( Scalar::Util::openhandle( $io ) );
-    # $self->message( 3, "Is file handle '$io' active ? (", ( defined( $io ) && $io->opened ) ? 'yes' : 'no', ")." );
     
     my( $offtype, $offset, $numbytes, $type, $mask, $op, $testval, $template, $message, $subtests ) = @$item;
-    ## $self->message( 5, "Checking item for description $$p_desc: ", sub{ $self->SUPER::dump( $item ) }) if( scalar( @$item ) );
     $self->{trick}++;
     if( $self->{trick} > 186 && $self->{trick} < 192 )
     {
-        ## $self->message( 4, "$item\n" );
         my $c = -1;
-        ## $self->message( 4, join( "\n", map{ sprintf( "%s: %s", $_, $item->[ ++$c ] ) } qw( offtype offset numbytes type mask op testval template message subtests ) ), "\n--------\n" );
     }
     ## Bytes from file
     my $data = '';
@@ -982,7 +960,6 @@ sub _magic_match
         {
             # return( $self->error( "Unable to read $numbytes bytes of data from file. Buffer is only ", length( $data ), " bytes." ) ) if( $io->read( $data, $numbytes ) != $numbytes );
             return if( $io->read( $data, $numbytes ) != $numbytes );
-            ## $self->message( 5, "Data now contains '$data'." );
         }
         else 
         {
@@ -993,7 +970,6 @@ sub _magic_match
                 $ch = $io->getc();
             }
         }
-        ## $self->message( 4, "Checking data '$data' against test value '$testval'\n" );
     
         ## Now do the comparison
         if( $op eq '=' ) 
