@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Apache2 Server Side Include Parser - ~/lib/Apache2/SSI/SharedMem.pm
-## Version v0.1.0
+## Version v0.1.1
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/01/18
-## Modified 2021/01/23
+## Modified 2022/10/21
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -17,6 +17,7 @@ BEGIN
     use warnings;
     use warnings::register;
     use parent qw( Module::Generic );
+    use vars qw( $VERSION $SUPPORTED_RE $SYSV_SUPPORTED $SEMOP_ARGS @EXPORT_OK %EXPORT_TAGS $N $SHEM_REPO );
     use Config;
     use JSON ();
     use Nice::Try;
@@ -32,8 +33,8 @@ BEGIN
     use constant LOCK_EX        =>  2;
     use constant LOCK_NB        =>  4;
     use constant LOCK_UN        =>  8;
-    ## if( $^O =~ /^(?:Android|cygwin|dos|MSWin32|os2|VMS|riscos)/ )
-    ## Even better
+    # if( $^O =~ /^(?:Android|cygwin|dos|MSWin32|os2|VMS|riscos)/ )
+    # Even better
     our $SUPPORTED_RE = qr/\bIPC\/SysV\b/m;
     if( $Config{extensions} =~ m/$SUPPORTED_RE/ && 
         ## No support for threads
@@ -99,9 +100,12 @@ EOT
     # Credits IPC::Shareable
     our $N = do { my $foo = eval { pack "L!", 0 }; $@ ? '' : '!' };
     our $SHEM_REPO = {};
-    our $VERSION = 'v0.1.0';
+    our $VERSION = 'v0.1.1';
 };
 
+use strict;
+use warnings;
+
 sub init
 {
     my $self = shift( @_ );
@@ -109,7 +113,7 @@ sub init
     $self->{create}     = 0;
     $self->{destroy}    = 0;
     $self->{exclusive}  = 0;
-    $self->{key}        = IPC_PRIVATE;
+    $self->{key}        = &IPC::SysV::IPC_PRIVATE;
     $self->{mode}       = 0666;
     $self->{serial}     = '';
     ## SHM_BUFSIZ
@@ -186,30 +190,26 @@ sub exists
     }
     my $flags = $self->flags({ mode => 0644 });
     # Remove the create bit
-    $flags = ( $flags ^ IPC_CREAT );
-    ## $self->message( 3, "Checking if shared memory key \"", ( $opts->{key} || $self->key ), "\" exists with flags '$flags'." );
+    $flags = ( $flags ^ &IPC::SysV::IPC_CREAT );
     my $semid;
     try
     {
         $semid = semget( $serial, 3, $flags );
-        ## $self->message( 3, "Found the shared memory? ", defined( $semid ) ? 'yes' : 'no' );
         if( defined( $semid ) )
         {
-            my $found = semctl( $semid, SEM_MARKER, GETVAL, 0 );
-            semctl( $semid, 0, IPC_RMID, 0 );
+            my $found = semctl( $semid, SEM_MARKER, &IPC::SysV::GETVAL, 0 );
+            semctl( $semid, 0, &IPC::SysV::IPC_RMID, 0 );
             return( $found == SHM_EXISTS ? 1 : 0 );
         }
         else
         {
-            ## $self->message( 3, "Error getting a semaphore: $!" );
             return( 0 ) if( $! =~ /\bNo[[:blank:]]+such[[:blank:]]+file\b/ );
             return;
         }
     }
     catch( $e )
     {
-        ## $self->message( 3, "Trying to access shared memory triggered error: $e" );
-        semctl( $semid, 0, IPC_RMID, 0 ) if( $semid );
+        semctl( $semid, 0, &IPC::SysV::IPC_RMID, 0 ) if( $semid );
         return( 0 );
     }
 }
@@ -224,18 +224,13 @@ sub flags
         : !( scalar( @_ ) % 2 )
             ? { @_ }
             : {};
-    ## $self->message( 3, "Option mode value is '$opts->{mode}'." );
     $opts->{create} = $self->create unless( length( $opts->{create} ) );
     $opts->{exclusive} = $self->exclusive unless( length( $opts->{exclusive} ) );
     $opts->{mode} = $self->mode unless( length( $opts->{mode} ) );
     my $flags  = 0;
-    ## $self->message( 3, "Adding create bit" ) if( $opts->{create} );
-    $flags    |= IPC_CREAT if( $opts->{create} );
-    ## $self->message( 3, "Adding exclusive bit" ) if( $opts->{exclusive} );
-    $flags    |= IPC_EXCL  if( $opts->{exclusive} );
-    ## $self->message( 3, "Adding mode '", ( $opts->{mode} || 0666 ), "'" );
+    $flags    |= &IPC::SysV::IPC_CREAT if( $opts->{create} );
+    $flags    |= &IPC::SysV::IPC_EXCL  if( $opts->{exclusive} );
     $flags    |= ( $opts->{mode} || 0666 );
-    ## $self->message( 3, "Returning flags value '$flags'." );
     return( $flags );
 }
 
@@ -245,13 +240,10 @@ sub id
     my $self = shift( @_ );
     my @callinfo = caller;
     no warnings 'uninitialized';
-    ## $self->message( 3, "Called from package $callinfo[0] in file $callinfo[1] at line $callinfo[2] with ", scalar( @_ ) ? ( "args: '" . join( "', '", @_ ) . "'." ) : 'no argument.' );
     if( @_ )
     {
-        ## $self->message( 3, "Setting id to value '", defined( $_[0] ) ? $_[0] : 'undef()', "'." );
         $self->{id} = shift( @_ );
     }
-    ## $self->message( 3, "Returning id '$self->{id}'" );
     return( $self->{id} );
 }
 
@@ -262,7 +254,6 @@ sub key
     {
         $self->{key} = shift( @_ );
         $self->{serial} = $self->_str2key( $self->{key} );
-        ## $self->message( 3, "Setting key to '$self->{key}' ($self->{serial})" );
     }
     return( $self->{key} );
 }
@@ -281,7 +272,6 @@ sub lock
     $self->unlock if( $self->locked );
     my $semid = $self->semid ||
         return( $self->error( "No semaphore id set yet." ) );
-    ## $self->message( 3, "Setting a lock on semaphore id \"$semid\" with type \"$type\" and arguments: ", sub{ $self->dump( $SEMOP_ARGS->{ $type } ) } );
     try
     {
         local $SIG{ALRM} = sub{ die( "timeout" ); };
@@ -294,7 +284,6 @@ sub lock
         }
         else
         {
-            ## $self->message( 3, "Unable to set a lock on semaphore id \"$semid\": $!" );
             return( $self->error( "Failed to set a lock on semaphore id \"$semid\": $!" ) );
         }
     }
@@ -360,22 +349,18 @@ sub open
         $create = $self->create;
     }
     my $flags = $self->flags( create => $create );
-    ## $self->message( 3, "Trying to get the shared memory segment with key '", ( $opts->{key} || $self->key ), "' with serial '$serial', size '$opts->{size}' and mode '$opts->{mode}'." );
     my $id = shmget( $serial, $opts->{size}, $flags );
     if( defined( $id ) )
     {
-        ## $self->message( 3, "Got the shared memory first time around with id \"$id\"." );
     }
     else
     {
-        ## $self->message( 3, "Shared memory does not exists yet ($!), trying to create it now start from $serial" );
-        my $newflags = ( $flags & IPC_CREAT ) ? $flags : ( $flags | IPC_CREAT );
+        my $newflags = ( $flags & &IPC::SysV::IPC_CREAT ) ? $flags : ( $flags | &IPC::SysV::IPC_CREAT );
         my $limit = ( $serial + 10 );
-        ## IPC::SysV::ftok has likely made the serial unique, but as stated in the manual page, there is no guarantee
+        # IPC::SysV::ftok has likely made the serial unique, but as stated in the manual page, there is no guarantee
         while( $serial <= $limit )
         {
-            $id = shmget( $serial, $opts->{size}, $newflags | IPC_CREAT );
-            ## $self->message( 3, "Shared memory key '$serial' worked ? ", defined( $serial ) ? 'yes' : 'no' );
+            $id = shmget( $serial, $opts->{size}, $newflags | &IPC::SysV::IPC_CREAT );
             $serial++;
             last if( defined( $id ) );
         }
@@ -383,23 +368,18 @@ sub open
     
     if( !defined( $id ) )
     {
-        ## $self->message( 3, "Could not open shared memory with flags '$flags': $!" );
         return( $self->error( "Unable to create shared memory id with key \"$serial\" and flags \"$flags\": $!" ) );
     }
     $self->serial( $serial );
     
-    ## $self->message( 3, "Shared memory created with id \"$id\"." );
     ## The value 3 can be anything above 0 and below the limit set by SEMMSL. On Linux system, this is usually 32,000. Seem semget(2) man page
     my $semid = semget( $serial, 3, $flags );
     if( !defined( $semid ) )
     {
-        ## $self->message( 3, "Could not get a semaphore, trying again with creating it." );
-        my $newflags = ( $flags | IPC_CREAT );
+        my $newflags = ( $flags | &IPC::SysV::IPC_CREAT );
         $semid = semget( $serial, 3, $newflags );
         return( $self->error( "Unable to get a semaphore for shared memory key \"", ( $opts->{key} || $self->key ), "\" wth id \"$id\": $!" ) ) if( !defined( $semid ) );
-        ## $self->message( 3, "Retrieved existing semaphore with semaphore id \"$semid\"." );
     }
-    ## $self->message( 3, "Semaphore id is '$semid'" );
     my $new = $self->new(
         key     => $opts->{key} || $self->key,
         debug   => $self->debug,
@@ -418,19 +398,15 @@ sub open
     $new->flags( $flags );
     if( $there == SHM_EXISTS )
     {
-        ## $self->message( 3, "Binding to existing segment on ", $new->id );
     }
     else
     {
-        ## $self->message( 3, "New segment on ", $new->id );
         ## We initialise the semaphore with value of 1
         $new->stat( SEM_MARKER, SHM_EXISTS ) ||
             return( $self->error( "Unable to set semaphore during object creation: $!" ) );
-        ## $self->message( 3, "Semaphore created." );
         $SHEM_REPO->{ $id } = $new;
     }
     $new->op( @{$SEMOP_ARGS->{(LOCK_SH | LOCK_UN)}} );
-    ## $self->message( 3, "Returning new object persuant to open" );
     return( $new );
 }
 
@@ -441,8 +417,8 @@ sub pid
     my $self = shift( @_ );
     my $sem  = shift( @_ );
     my $semid = $self->semid ||
-        return( $self->error( "No semaphore set yet. You must open the shared memory first to remove semaphore." ) ) if( !length( $id ) );
-    my $v = semctl( $semid, $sem, GETPID, 0 );
+        return( $self->error( "No semaphore set yet. You must open the shared memory first to remove semaphore." ) );
+    my $v = semctl( $semid, $sem, &IPC::SysV::GETPID, 0 );
     return( $v ? 0 + $v : undef() );
 }
 
@@ -450,7 +426,7 @@ sub rand
 {
     my $self = shift( @_ );
     my $size = $self->size || 1024;
-    my $key  = shmget( IPC_PRIVATE, $size, S_IRWXU|S_IRWXG|S_IRWXO ) ||
+    my $key  = shmget( &IPC::SysV::IPC_PRIVATE, $size, &IPC::SysV::S_IRWXU|&IPC::SysV::S_IRWXG|&IPC::SysV::S_IRWXO ) ||
         return( $self->error( "Unable to generate a share memory key: $!" ) );
     return( $key );
 }
@@ -462,7 +438,6 @@ sub read
     my $id     = $self->id;
     ## Optional length parameter for non-reference data only
     my $size   = int( $_[1] || $self->size || SHM_BUFSIZ );
-    ## $self->message( 3, "Reading $size bytes of data from memory for id '$id'." );
     return( $self->error( "No shared memory id! Have you opened it first?" ) ) if( !length( $id ) );
     my $buffer = '';
     my $addr = $self->addr;
@@ -478,7 +453,6 @@ sub read
     }
     ## Get rid of nulls end padded
     $buffer = unpack( "A*", $buffer );
-    ## $self->message( 3, "Data retrieved is '$buffer'." );
     my $first_char = substr( $buffer, 0, 1 );
     my $j = JSON->new->utf8->relaxed->allow_nonref;
     my $data;
@@ -514,20 +488,20 @@ sub read
     {
         my $len = length( $_[0] );
         ## If the decoded data is not a reference of any sort, and the length parameter was provided
-		if( !ref( $data ) )
-		{
-			$_[0] = $size > 0 ? substr( $data, 0, $size ) : $data;
-			return( length( $_[0] ) || "0E0" );
-		}
-		else
-		{
-			$_[0] = $data;
-			return( $len || "0E0" );
-		}
+        if( !ref( $data ) )
+        {
+            $_[0] = $size > 0 ? substr( $data, 0, $size ) : $data;
+            return( length( $_[0] ) || "0E0" );
+        }
+        else
+        {
+            $_[0] = $data;
+            return( $len || "0E0" );
+        }
     }
     else
     {
-		return( $data );
+        return( $data );
     }
 }
 
@@ -536,19 +510,18 @@ sub remove
     my $self = shift( @_ );
     return( 1 ) if( $self->removed );
     my $id   = $self->id();
-    ## $self->message( 3, "Called to remove shared memory id \"$id\"." );
     return( $self->error( "No shared memory id! Have you opened it first?" ) ) if( !length( $id ) );
     my $semid = $self->semid;
     return( $self->error( "No semaphore set yet. You must open the shared memory first to remove semaphore." ) ) if( !length( $semid ) );
     $self->unlock();
-    ## Remove share memory segment
-    if( !defined( shmctl( $id, IPC_RMID, 0 ) ) )
+    # Remove share memory segment
+    if( !defined( shmctl( $id, &IPC::SysV::IPC_RMID, 0 ) ) )
     {
-        return( $self->error( "Unable to remove share memory segement id '$id' (IPC_RMID is '", IPC_RMID, "'): $!" ) );
+        return( $self->error( "Unable to remove share memory segement id '$id' (IPC_RMID is '", &IPC::SysV::IPC_RMID, "'): $!" ) );
     }
     ## Remove semaphore
     my $rv;
-    if( !defined( $rv = semctl( $semid, 0, IPC_RMID, 0 ) ) )
+    if( !defined( $rv = semctl( $semid, 0, &IPC::SysV::IPC_RMID, 0 ) ) )
     {
         $self->error( "Warning only: could not remove the semaphore id \"$semid\": $!" );
     }
@@ -580,15 +553,13 @@ sub stat
         if( @_ == 1 )
         {
             my $sem = shift( @_ );
-            ## $self->message( 3, "Retrieving semaphore value for '$sem'" );
-            my $v = semctl( $id, $sem, GETVAL, 0 );
+            my $v = semctl( $id, $sem, &IPC::SysV::GETVAL, 0 );
             return( $v ? 0 + $v : undef() );
         }
         else
         {
             my( $sem, $val ) = @_;
-            ## $self->message( 3, "Setting semaphore '$sem' with value '$val'." );
-            return( semctl( $id, $sem, SETVAL, $val ) );
+            return( semctl( $id, $sem, &IPC::SysV::SETVAL, $val ) );
         }
     }
     else
@@ -596,14 +567,12 @@ sub stat
         my $data = '';
         if( wantarray() )
         {
-            ## $self->message( 3, "Returning all semaphore data." );
-            semctl( $id, 0, GETALL, $data ) || return( () );
+            semctl( $id, 0, &IPC::SysV::GETALL, $data ) || return( () );
             return( ( unpack( "s*", $data ) ) );
         }
         else
         {
-            ## $self->message( 3, "Returning all semaphore data as Apache2::SSI::SemStat object." );
-            semctl( $id, 0, IPC_STAT, $data ) ||
+            semctl( $id, 0, &IPC::SysV::IPC_STAT, $data ) ||
                 return( $self->error( "Unable to stat semaphore with id '$id': $!" ) );
             return( Apache2::SSI::SemStat->new->unpack( $data ) );
         }
@@ -618,7 +587,6 @@ sub unlock
     return( 1 ) if( !$self->locked );
     my $semid = $self->semid;
     return( $self->error( "No semaphore set yet. You must open the shared memory first to unlock semaphore." ) ) if( !length( $semid ) );
-    ## $self->message( 3, "Removing lock for semaphore id \"$semid\" and locked value '$self->{locked}'." );
     my $type = $self->locked | LOCK_UN;
     $type ^= LOCK_NB if( $type & LOCK_NB );
     if( defined( $self->op( @{$SEMOP_ARGS->{ $type }} ) ) )
@@ -635,8 +603,6 @@ sub write
     my $id   = $self->id();
     my $size = int( $self->size() ) || SHM_BUFSIZ;
     my @callinfo = caller;
-    ## $self->message( 3, "Called from file $callinfo[1] at line $callinfo[2]" );
-    ## $self->message( 3, "Size limit set to '$size'" );
     my $j = JSON->new->utf8->relaxed->allow_nonref->convert_blessed;
     my $encoded;
     try
@@ -652,7 +618,6 @@ sub write
     {
         return( $self->error( "Data to write are ", length( $encoded ), " bytes long and exceed the maximum you have set of '$size'." ) );
     }
-    ## $self->message( 3, "Storing ", length( $encoded ), " bytes of data", ( length( $encoded ) <= 2048 ? ":\n'$encoded'" : '.' ) );
     ## $size = length( $encoded );
     my $addr = $self->addr;
     if( $addr )
@@ -665,7 +630,6 @@ sub write
         shmwrite( $id, $encoded, 0, $size ) ||
             return( $self->error( "Unable to write to shared memory id '$id': $!" ) );
     }
-    ## $self->message( 3, "Successfully wrote ", length( $encoded ), " bytes of data to memory." );
     return( $self );
 }
 
@@ -675,7 +639,7 @@ sub _str2key
     my $key  = shift( @_ );
     if( !defined( $key ) || $key eq '' )
     {
-        return( IPC_PRIVATE );
+        return( &IPC::SysV::IPC_PRIVATE );
     }
     elsif( $key =~ /^\d+$/ )
     {
@@ -688,7 +652,6 @@ sub _str2key
         ## We use the root as a reliable and stable path.
         ## I initially though about using __FILE__, but during testing this would be in ./blib/lib and beside one user might use a version of this module somewhere while the one used under Apache/mod_perl2 could be somewhere else and this would render the generation of the IPC key unreliable and unrepeatable
         my $val = IPC::SysV::ftok( '/', $id );
-        ## $self->message( 3, "Calling IPC::SysV::ftok for key '$key' with file '/' and numeric id '$id' returning '$val'." );
         return( $val );
     }
 }
@@ -698,7 +661,6 @@ END
     foreach my $id ( keys( %$SHEM_REPO ) )
     {
         my $s = $SHEM_REPO->{ $id };
-        $s->message( 3, "Cleaning up for shared memory id '$id' with destroy value '", $s->destroy, "' and owner '", $s->owner, "' vs pid '$$'." );
         $s->unlock;
         next unless( $s->destroy );
         next unless( $s->owner == $$ );
@@ -756,4 +718,3 @@ END
 }
 
 1;
-
