@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## Apache2 Server Side Include Parser - ~/lib/Apache2/SSI/URI.pm
-## Version v0.1.1
+## Version v0.1.2
 ## Copyright(c) 2021 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2020/12/18
-## Modified 2021/02/01
+## Modified 2022/10/21
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -16,11 +16,12 @@ BEGIN
     use strict;
     use warnings::register;
     use parent qw( Apache2::SSI::Common );
+    use vars qw( $VERSION $DEBUG $DIR_SEP );
     use Apache2::SSI::Finfo;
     use Cwd;
     use File::Spec ();
-    ## Used for debugging
-    ## use Devel::Confess;
+    # Used for debugging
+    # use Devel::Confess;
     use Nice::Try;
     use Scalar::Util ();
     require constant;
@@ -36,33 +37,36 @@ BEGIN
         require Apache2::Const;
         Apache2::Const->import( compile => qw( :common :http OK DECLINED ) );
     }
-    ## use Devel::Confess;
+    # use Devel::Confess;
     our( $DEBUG );
     use overload (
         q{""}    => sub    { $_[0]->document_uri->as_string },
         bool     => sub () { 1 },
         fallback => 1,
     );
-    our $VERSION = 'v0.1.1';
+    our $VERSION = 'v0.1.2';
     our $DIR_SEP = $Apache2::SSI::Common::DIR_SEP;
 };
 
-## document_root = /home/joe/www
-## base_uri      = /my/uri/file.html/some/path/info?q=something&l=ja_JP
-## base_uri is the current reference document
-## document_uri  = ./about.html
-## document_uri is the uri which is the purpose of this object. It will be made absolute and its dots flattened
-## Example: ../about.html?q=hello would become /my/about.html?q=hello
+use strict;
+use warnings;
+
+# document_root = /home/joe/www
+# base_uri      = /my/uri/file.html/some/path/info?q=something&l=ja_JP
+# base_uri is the current reference document
+# document_uri  = ./about.html
+# document_uri is the uri which is the purpose of this object. It will be made absolute and its dots flattened
+# Example: ../about.html?q=hello would become /my/about.html?q=hello
 sub init
 {
     my $self = shift( @_ );
     $self->{apache_request} = '';
     $self->{base_uri}       = '/' unless( length( $self->{base_uri} ) );
-    ## By default
+    # By default
     $self->{code}           = 200;
     $self->{document_path}  = '';
     $self->{document_root}  = '';
-    ## Reference document for the main request
+    # Reference document for the main request
     $self->{document_uri}   = '';
     $self->{filepath}       = '';
     $self->{finfo}          = '';
@@ -74,13 +78,12 @@ sub init
     $self->{_uri_reset}      = 0;
     $self->{document_root} ||= $self->env( 'DOCUMENT_ROOT' );
     $self->{base_uri}      ||= $self->env( 'DOCUMENT_URI' );
-    ## $self->message( 4, "Apache RequestRec object provided ? '$self->{apache_request}' for document uri '$self->{document_uri}'." );
     return( $self->error( "No document root was provided." ) ) if( !length( $self->{document_root} ) );
     return( $self->error( "No base uri was provided." ) ) if( !length( $self->{base_uri} ) );
     return( $self->error( "No document uri was provided." ) ) if( !length( $self->{document_uri} ) );
-    ## Small correction if necessary. If the base uri is a directory, it needs to have a trailing "/", so URI knows this is a directory and not a file.
-    ## URI->new( "./file.pl" )->abs( "/ssi/plop" ) becomes "/ssi/file.pl" whereas it should be /ssi/plop/file.pl
-    ## $self->{base_uri} .= '/' if( length( $self->{base_uri} ) && -d( "$self->{document_root}$self->{base_uri}" ) && substr( $self->{base_uri}, -1, 1 ) ne '/' );
+    # Small correction if necessary. If the base uri is a directory, it needs to have a trailing "/", so URI knows this is a directory and not a file.
+    # URI->new( "./file.pl" )->abs( "/ssi/plop" ) becomes "/ssi/file.pl" whereas it should be /ssi/plop/file.pl
+    # $self->{base_uri} .= '/' if( length( $self->{base_uri} ) && -d( "$self->{document_root}$self->{base_uri}" ) && substr( $self->{base_uri}, -1, 1 ) ne '/' );
     return( $self );
 }
 
@@ -107,17 +110,14 @@ sub base_dir
         my $rr = $self->lookup_uri( $dir_path );
         if( !defined( $rr ) )
         {
-            $self->message( 3, "Error occured looking up uri '$path': ", $self->error );
             return;
         }
-        elsif( $rr->status != Apache2::Const::HTTP_OK )
+        elsif( $rr->status != &Apache2::Const::HTTP_OK )
         {
-            $self->message( 3, "There was an error looking up bas directory \"$dir_path\"." );
             return( $self->error( "Could not look up base directory \"$dir_path\". Returned code is: ", $rr->status ) );
         }
-        elsif( $rr->finfo->filetype == APR::Const::FILETYPE_NOFILE )
+        elsif( $rr->finfo->filetype == &APR::Const::FILETYPE_NOFILE )
         {
-            $self->message( 3, "Base directory \"$dir_path\" is not found." );
             return( $self->error( "Could not find base directory \"$dir_path\"." ) );
         }
         ## Remove trailing slash
@@ -171,40 +171,33 @@ sub base_uri
     
     unless( length( $new ) )
     {
-        $self->message( 4, "Returning base_uri object '", overload::StrVal( $self->{base_uri} ), "' (", ref( $self->{base_uri} ), ")." );
         return( $self->{base_uri} );
     }
     
-    $self->message( 4, "Processing new base uri '$new'." );
     my $r = $self->apache_request;
     ## We create an URI object, so we can get the path only
     my $u = $self->new_uri( $new );
     my $path = $u->path;
     if( $r )
     {
-        $self->message( 3, "Looking up uri \"$path\"." );
         my $rr = $self->lookup_uri( $path );
         if( !defined( $rr ) )
         {
-            $self->message( 3, "Error occured looking up uri '$path': ", $self->error );
             return;
         }
-        elsif( $rr->status != Apache2::Const::HTTP_OK )
+        elsif( $rr->status != &Apache2::Const::HTTP_OK )
         {
             my $hdrs = $rr->headers_out;
-            $self->message( 3, "There was an error looking up uri \"$path\" with resulting uri \"", $rr->uri, "\". Headers were: ", sub{ $self->dump( $hdrs ) } );
             return( $self->error( "Could not look up uri \"$path\". Returned code is: ", $rr->status ) );
         }
-        elsif( $rr->finfo->filetype == APR::Const::FILETYPE_NOFILE )
+        elsif( $rr->finfo->filetype == &APR::Const::FILETYPE_NOFILE )
         {
-            $self->message( 3, "URI \"$path\" is not found." );
             return( $self->error( "Could not find uri \"$path\" (originally $u)." ) );
         }
         
         ## Remove trailing slash
         my $u2 = $self->_trim_trailing_slash( $rr->unparsed_uri );
         
-        $self->message( 3, "Setting base_uri value via document_uri to '$u2'. Path info found '", $rr->path_info, "'" );
         my $hash =
         {
         apache_request => $r,
@@ -218,7 +211,7 @@ sub base_uri
         query_string => scalar( $rr->args ),
         _path_info_processed => 1,
         };
-        if( $rr->finfo->filetype == APR::Const::FILETYPE_DIR )
+        if( $rr->finfo->filetype == &APR::Const::FILETYPE_DIR )
         {
             $self->{base_dir} = bless( $hash => ref( $self ) );
         }
@@ -226,21 +219,16 @@ sub base_uri
     }
     else
     {
-        $self->message( 4, "Resolving uri \"$path\"." );
         ## We need to ensure the base uri is free of any path info or query string !
         my $ref = $self->_find_path_info( $u->path );
-        $self->message( 4, "_find_path_info reslulted in: ", sub{ $self->dump( $ref ) });
         if( !defined( $ref ) )
         {
-            $self->message( 3, "Error resolving \"$path\"." );
             return( $self->error( "Unable to resolve \"$u\"." ) );
         }
         elsif( $ref->{code} != 200 )
         {
-            $self->message( 3, "URI \"$path\" is not found." );
             $self->error( "Failed to resolve \"$u\". Resulting code is '$ref->{code}'." );
         }
-        $self->message( 4, "Creating object." );
         my $hash =
         {
         base_dir => $self->root,
@@ -258,7 +246,6 @@ sub base_uri
         $self->{base_dir} = bless( $hash => ref( $self ) ) if( -d( $ref->{path} ) );
         $self->{base_uri} = bless( $hash => ref( $self ) );
     }
-    $self->message( 3, "Returning base_uri: '", overload::StrVal( $self->{base_uri} ), "' ($self->{base_uri})." );
     return( $self->{base_uri} );
 }
 
@@ -298,10 +285,8 @@ sub document_directory
     my $self = shift( @_ );
     my $doc_path = $self->document_path || return( $self->error( "No document path set." ) );
     my $doc_root = $self->document_root || return( $self->error( "No document root set." ) );
-    $self->message( 3, "Document path is '$doc_path' and document root is '$doc_root'." );
     return( $self->make( document_uri => $doc_path ) ) if( -e( "${doc_root}${doc_path}" ) && -d( _ ) );
     my $parent = $self->parent;
-    $self->message( 3, "Returning parent '$parent'." );
     return( $parent );
 }
 
@@ -312,24 +297,20 @@ sub document_path
     my $self = shift( @_ );
     my $class = ref( $self );
     my $caller = (caller(1))[3] // '';
-    ## my $caller = substr( $sub, rindex( $sub, ':' ) + 1 );
+    # my $caller = substr( $sub, rindex( $sub, ':' ) + 1 );
     my $r = $self->apache_request;
     if( $r )
     {
         if( @_ )
         {
             my $uri = shift( @_ );
-            $self->message( 4, "Looking up document path '$uri'." );
             $r = $r->is_initial_req ? $r : $r->main;
             my $rr = $self->lookup_uri( $uri );
             if( !defined( $rr ) )
             {
-                $self->message( 3, "Error occured looking up uri '$path': ", $self->error );
                 return;
             }
-            $self->message( 4, "New path looked up is '", $rr->uri, "'." );
             my $u = APR::URI->parse( $rr->pool, $r->uri );
-            $self->message( 4, "Document parsed derived from '", $rr->uri, "' by APR::URI is: '", $u->rpath, "'." );
             ## Remove trailing slash
             my $u2 = $self->_trim_trailing_slash( $u->rpath );
             $self->{document_path} = $u2;
@@ -337,9 +318,7 @@ sub document_path
         }
         elsif( !length( $self->{document_path} ) )
         {
-            $self->message( 4, "No document path set. Guessing it from \$r->uri '", $r->uri, "'." );
             my $u = APR::URI->parse( $r->pool, $r->uri );
-            $self->message( 3, "Setting document path to '", $u->rpath, "'." );
             $self->{document_path} = $self->new_uri( $u->rpath );
         }
     }
@@ -348,9 +327,7 @@ sub document_path
         if( @_ )
         {
             my $uri = shift( @_ );
-            $self->message( 4, "Setting new document path for '$uri'." );
             $self->{document_path} = $self->new_uri( $self->collapse_dots( $uri ) );
-            $self->message( 3, "Document path value is now: '", $self->{document_path}, "' (", overload::StrVal( $self->{document_path} ), ")." );
             $self->{_uri_reset} = 'document_path' unless( $caller eq "${class}\::document_uri" );
         }
     }
@@ -365,7 +342,6 @@ sub document_root
     if( @_ )
     {
         $new = shift( @_ );
-        $self->message( 4, "New document root provided: '$new'." );
         # unless( substr( $new, 0, 1 ) eq '/' )
         unless( File::Spec->file_name_is_absolute( $new ) )
         {
@@ -398,13 +374,10 @@ sub document_uri
     if( @_ )
     {
         $new = shift( @_ );
-        $self->message( 3, "New document uri provided '$new'." );
         local $URI::ABS_REMOTE_LEADING_DOTS = 1;
         unless( substr( "$new", 0, 1 ) eq '/' )
         {
             my $base_uri = $self->base_uri;
-            $self->message( 4, "New document uri '$new' is not absolute. Making it absolute using base uri '", $base_uri->{document_path}, "'." );
-            $self->message( 4, "Base uri is '", overload::StrVal( $base_uri ), "' ($base_uri)." );
             $new = URI->new( $new )->abs( $base_uri->{document_path} );
         }
     }
@@ -413,18 +386,16 @@ sub document_uri
     
     if( $r )
     {
-        ## We do a lookup unless we are already in a sub request, and we do not want to end up in an infinite loop
-        ## $r = $r->is_initial_req ? $r : $r->main;
+        # We do a lookup unless we are already in a sub request, and we do not want to end up in an infinite loop
+        # $r = $r->is_initial_req ? $r : $r->main;
         if( length( "$new" ) )
         {
             $r = $r->is_initial_req ? $r : $r->main;
             my $rr = $self->lookup_uri( "$new" );
             if( !defined( $rr ) )
             {
-                $self->message( 3, "Error occured looking up uri '$path': ", $self->error );
                 return;
             }
-            $self->message( 3, "Resulting uri from lookup_uri is \"", $rr->uri, "\" (", $rr->unparsed_uri, ")." );
             $self->apache_request( $rr );
             ## Remove trailing slash
             my $u = $self->_trim_trailing_slash( $rr->unparsed_uri );
@@ -436,25 +407,21 @@ sub document_uri
         }
         elsif( $self->{_uri_reset} )
         {
-            $self->message( 4, "URI has been reset by '$self->{_uri_reset}'" );
             my $u = URI->new( $r->uri . ( $r->path_info // '' ) );
             $u->query( scalar( $r->args ) ) if( length( scalar( $r->args ) ) );
             ## Cannot change the value of $r->unparsed_uri
             $r->uri( "$u" );
-            $self->message( 4, "Document uri has been updated after reset to '$self->{document_uri}'." );
             $self->{document_uri} = $u;
             $self->{_uri_reset} = 0;
         }
         elsif( !length( $self->{document_uri} ) )
         {
-            $self->message( 3, "URI not set or reset. Using '", $r->unparsed_uri, "'." );
             $self->{document_uri} = $self->new_uri( $r->unparsed_uri );
             $self->_set_env( DOCUMENT_URI => $self->{document_uri} );
             $self->_set_env( REQUEST_URI => $self->{document_uri} );
             $self->_set_env( QUERY_STRING => scalar( $r->args ) ) if( scalar( $r->args ) );
             $self->_set_env( PATH_INFO => $r->path_info ) if( $r->path_info );
         }
-        $self->message( 4, "Returning document uri value of '$self->{document_uri}'." );
         return( $self->{document_uri} );
     }
     else
@@ -463,49 +430,35 @@ sub document_uri
         {
             $self->{_path_info_processed} = 0;
         }
-        $self->message( 4, "Returning nothing." ) if( !length( $self->{document_uri} ) && $self->{_path_info_processed} );
         return( '' ) if( !length( $self->{document_uri} ) && $self->{_path_info_processed} );
         my $v = $new || $self->{document_uri};
-        $self->message( 3, "New document uri provided is '$new' (possibly null) and document_uri value is: '$self->{document_uri}'" );
         if( !$self->{_path_info_processed} )
         {
-            $self->message( 4, "Path info from document uri '$v' not processed yet, doing it now." );
             $self->{_path_info_processed}++;
             my $res;
             if( defined( $res = $self->_find_path_info( $v ) ) )
             {
-                $self->message( 4, "_find_path_info returned: ", sub{ $self->dump( $res ) });
                 $self->{document_uri} = URI->new( $v );
-                $self->message( 3, "Document uri set to '", ( $self->{document_uri} // '' ), "'" );
-                $self->message( 4, "Setting document_path to '", ( $res->{path} // '' ), "'" );
                 $self->document_path( $res->{path} );
-                $self->message( 4, "Setting filename to '", ( $res->{filepath} // '' ), "'" );
                 $self->filename( $res->{filepath} );
-                $self->message( 4, "Setting path_info to '", ( $res->{path_info} // '' ), "'" );
                 $self->path_info( $res->{path_info} ) if( length( $res->{path_info} ) );
-                $self->message( 4, "Setting query_string to '", ( $res->{query_string} // '' ), "'" );
                 $self->query_string( $res->{query_string} ) if( length( $res->{query_string} ) );
                 $self->_set_env( DOCUMENT_URI => $self->{document_uri} );
                 $self->_set_env( REQUEST_URI => $self->{document_uri} );
-                $self->message( 4, "Setting code to '$res->{code}'" );
                 $self->code( $res->{code} );
             }
             else
             {
-                $self->message( 3, "_find_path_info returned an error: ", $self->error );
             }
         }
         
         if( $self->{_uri_reset} )
         {
-            $self->message( 4, "URI has been reset by '$self->{_uri_reset}'" );
             $self->{_uri_reset} = 0;
             my $u = URI->new( $self->document_path . ( $self->path_info // '' ) );
             $u->query( $self->query_string ) if( $self->query_string );
             $self->{document_uri} = $u;
-            $self->message( 4, "Document uri reset to '$self->{document_uri}'" );
         }
-        $self->message( 4, "Returning document_uri = '$self->{document_uri}'" );
         return( $self->{document_uri} );
     }
 }
@@ -536,11 +489,11 @@ sub env
     my $opts = {};
     no warnings 'uninitialized';
     $opts = pop( @_ ) if( scalar( @_ ) && Scalar::Util::reftype( $_[-1] ) eq 'HASH' );
-    ## return( $self->error( "Environment variable value provided is a reference data (", overload::StrVal( $val ), ")." ) ) if( ref( $val ) && ( !overload::Overloaded( $val ) || ( overload::Overloaded( $val ) && !overload::Method( $val, '""' ) ) ) );
+    # return( $self->error( "Environment variable value provided is a reference data (", overload::StrVal( $val ), ")." ) ) if( ref( $val ) && ( !overload::Overloaded( $val ) || ( overload::Overloaded( $val ) && !overload::Method( $val, '""' ) ) ) );
     my $r = $opts->{apache_request} || $self->apache_request;
     if( $r )
     {
-        ## $r = $r->is_initial_req ? $r : $r->main;
+        # $r = $r->is_initial_req ? $r : $r->main;
         $r->subprocess_env( $name => shift( @_ ) ) if( @_ );
         my $v = $r->subprocess_env( $name );
         return( $v );
@@ -573,7 +526,7 @@ sub filename
     my $self = shift( @_ );
     my $class = ref( $self );
     my $caller = (caller(1))[3] // '';
-    ## my $caller = substr( $sub, rindex( $sub, ':' ) + 1 );
+    # my $caller = substr( $sub, rindex( $sub, ':' ) + 1 );
     my $r = $self->apache_request;
     my $newfile;
     if( @_ )
@@ -586,21 +539,17 @@ sub filename
     {
         if( defined( $newfile ) )
         {
-            $self->message( 4, "Setting new file path '$newfile'. Looking up file." );
             $r = $r->is_initial_req ? $r : $r->main;
             my $rr = $r->lookup_file( $newfile );
-            if( $rr->status == Apache2::Const::HTTP_OK )
+            if( $rr->status == &Apache2::Const::HTTP_OK )
             {
                 $newfile = $rr->filename;
-                $self->message( 3, "File found and resolved to: '$newfile'." );
             }
             else
             {
-                $self->message( 3, "File not found. Setting it to: '$newfile' nevertheless." );
                 $r->filename( $self->collapse_dots( $newfile, { separator => $DIR_SEP }) );
-                $self->message( 3, "File path is now '", $r->filename, "'." );
                 ## <https://perl.apache.org/docs/2.0/api/Apache2/RequestRec.html#toc_C_filename_>
-                $r->finfo( APR::Finfo::stat( $newfile, APR::Const::FINFO_NORM, $r->pool ) );
+                $r->finfo( APR::Finfo::stat( $newfile, &APR::Const::FINFO_NORM, $r->pool ) );
                 $self->finfo( $newfile );
             }
             $r->subprocess_env( SCRIPT_FILENAME => $newfile );
@@ -617,7 +566,6 @@ sub filename
     {
         if( defined( $newfile ) )
         {
-            $self->message( 3, "New file path provided is: '$newfile'" );
             my $try = Cwd::realpath( $newfile );
             ## Cwd::realpath would convert
             ## Z:\perl\Apache2-SSI\t\htdocs\ssi\include.cgi
@@ -625,18 +573,15 @@ sub filename
             ## Z:/perl/Apache2-SSI/t/htdocs/ssi/include.cgi
             ## amazingly enough, so to make sure this keeps working on windows related platform, we need to call URI::file
             $newfile = URI::file->new( $try )->file( $^O ) if( defined( $try ) );
-            $self->message( 3, "Getting the new file real path: '$newfile'" );
             unless( File::Spec->file_name_is_absolute( $newfile ) )
             {
                 $newfile = URI::file->new_abs( $newfile )->file( $^O );
-                $self->message( 3, "Made file provided absolute => $newfile" );
             }
             $self->env( SCRIPT_FILENAME => $newfile );
             $self->finfo( $newfile );
             ## Force to create new Apache2::SSI::URI object
             ## Either a URI object or an URI::file object
             $self->{filename} = $self->collapse_dots( $newfile, { separator => $DIR_SEP })->file( $^O );
-            $self->message( 3, "After collapsing dots, filename is '$self->{filename}'." );
             ## Pass the file as new argument to URI::file which will create an object based on the value of the current OS
             ## and transform it into a path à la linux, which is same as web, which is what we want
             ## All this is unnecessary for linux type system or those who use / as directory separator,
@@ -649,11 +594,9 @@ sub filename
             {
                 $self->{document_path} = $self->new_uri( URI::file->new( $self->{filename} )->file( 'linux' ) );
             }
-            $self->message( 3, "Document path is set to '$self->{document_path}'" );
             $self->{_uri_reset} = 'filename' unless( $caller eq "${class}\::document_uri" );
         }
     }
-    $self->message( 4, "Returning filename '$self->{filename}'" );
     return( $self->{filename} );
 }
 
@@ -678,7 +621,6 @@ sub finfo
     
     if( defined( $newfile ) )
     {
-        $self->message( 3, "No finfo object yet, creating one with file '$newfile'." );
         $self->{finfo} = Apache2::SSI::Finfo->new( $newfile, ( $r ? ( apache_request => $r ) : () ), debug => $self->debug );
         return( $self->pass_error( Apache2::SSI::Finfo->error ) ) if( !$self->{finfo} );
     }
@@ -703,10 +645,9 @@ sub lookup_uri
     my $c = 0;
     my $rr = $r->lookup_uri( $uri );
     while( ++$c <= $max_redirects && 
-           ( $rr->status == Apache2::Const::HTTP_MOVED_PERMANENTLY || 
-             $rr->status == Apache2::Const::HTTP_MOVED_TEMPORARILY ) )
+           ( $rr->status == &Apache2::Const::HTTP_MOVED_PERMANENTLY || 
+             $rr->status == &Apache2::Const::HTTP_MOVED_TEMPORARILY ) )
     {
-        $self->message( 3, "Getting next \$r in redirect." );
         my $next_r = $rr->next;
         if( !defined( $next_r ) )
         {
@@ -714,21 +655,17 @@ sub lookup_uri
         }
         else
         {
-            $self->message( 3, "Resulting status is: ", $next_r->status );
             $rr = $next_r;
         }
     }
-    $self->message( 3, "Resulting Apache2::RequestRec is '$rr' with status '", $rr->status, "'." );
     if( defined( $rr ) && 
-        ( $rr->status == Apache2::Const::HTTP_MOVED_PERMANENTLY || 
-          $rr->status == Apache2::Const::HTTP_MOVED_TEMPORARILY ) )
+        ( $rr->status == &Apache2::Const::HTTP_MOVED_PERMANENTLY || 
+          $rr->status == &Apache2::Const::HTTP_MOVED_TEMPORARILY ) )
     {
         my $hdrs = $rr->headers_out;
-        $self->message( 3, "Redirect headers are: ", sub{ $self->dump( $hdrs ) });
         ## Weird, should not happen, but just in case
         if( !exists( $hdrs->{Location} ) || !length( $hdrs->{Location} ) )
         {
-            $self->message( 3, "Could not find any 'Location' header." );
             return( $rr );
         }
         
@@ -737,23 +674,19 @@ sub lookup_uri
             ## No, we cannot use $rr->uri. This would give us the initial requested uri, not the redirected uri
             my $u = URI->new( $hdrs->{Location} );
             $uri = $u->path;
-            $self->message( 3, "Found uri \"$uri\" from Location header field." );
             if( ++$self->{_lookup_looping} > 1 )
             {
-                $self->message( 3, "Lookup is looping, return current \$r '$rr'." );
                 return( $rr );
             }
             else
             {
                 delete( $self->{_lookup_looping} );
                 my $new_r = $self->lookup_uri( $uri );
-                $self->message( 3, "Returning new \$r '$new_r' with status '", $new_r->status, "' and uri '", $new_r->uri, "' and filename '", $new_r->filename, "'" );
                 return( $new_r );
             }
         }
         catch( $e )
         {
-            $self->message( 3, "An error occurred while creating URI object for \"$hdrs->{Location}\": $e" );
             $self->error( "An error occurred while creating URI object for \"$hdrs->{Location}\": $e" );
             return( $rr );
         }
@@ -785,7 +718,6 @@ sub make
     $p->{base_uri} = "$b" if( !$p->{base_uri} && length( $b ) );
     $p->{document_uri} = "$f" if( !$p->{document_uri} );
     $p->{debug} = $self->debug if( !length( $p->{debug} ) );
-    $self->message( 4, "Creating new file object with parameters: ", sub{ $self->dump( $p ) });
     return( $self->new( $p ) );
 }
 
@@ -810,12 +742,9 @@ sub parent
     my $path = $self->document_path;
     my $r = $self->apache_request;
     ## I deliberately did not do split( '/', $path, -1 ) so that if there is a trailing '/', it will not be counted
-    $self->message( 4, "Document path value is '$path' (", overload::StrVal( $path ), ")." );
     my @segments = $self->document_path->path_segments;
-    $self->message( 4, "Path segments are: ", sub{ $self->dump( \@segments )} );
     pop( @segments );
     return( $self ) if( !scalar( @segments ) );
-    $self->message( 4, "Creating new object with document uri '", join( '/', @segments ), "'." );
     return( $self->make( document_uri => join( '/', @segments ) ) );
 }
 
@@ -830,22 +759,17 @@ sub path_info
     {
         if( @_ )
         {
-            $self->message( 3, "Setting path info to '", $_[0], "'." );
             $r->path_info( shift( @_ ) );
-            $self->message( 4, "Path info updated with '", $r->path_info, "'." );
             $self->_set_env( PATH_INFO => $r->path_info );
             $self->{_uri_reset} = 'path_info' unless( $caller eq "${class}\::document_uri" );
         }
-        $self->message( 4, "Returning path info '", $r->path_info, "'." );
         return( $r->path_info );
     }
     else
     {
         if( @_ )
         {
-            $self->message( 3, "Setting path info to '", $_[0], "'." );
             $self->{path_info} = shift( @_ );
-            $self->message( 4, "Path info updated with '", $self->{path_info}, "'." );
             $self->_set_env( PATH_INFO => $self->{path_info} );
             $self->{_uri_reset} = 'path_info' unless( $caller eq "${class}\::document_uri" );
         }
@@ -865,9 +789,7 @@ sub query_string
         if( @_ )
         {
             my $qs = shift( @_ );
-            $self->message( 3, "Setting query string to '$qs'." );
             $r->args( $qs );
-            $self->message( 4, "Query string is now '", scalar( $r->args ), "'." );
             $self->_set_env( QUERY_STRING => $qs );
             $self->{_uri_reset} = 'query_string' unless( $caller eq "${class}\::document_uri" );
         }
@@ -877,9 +799,7 @@ sub query_string
     {
         if( @_ )
         {
-            $self->message( 3, "Setting query string to '", $_[0], "'." );
             $self->{query_string} = shift( @_ );
-            $self->message( 4, "Query string is now '", $self->{query_string}, "'." );
             $self->_set_env( QUERY_STRING => $self->{query_string} );
             $self->{_uri_reset} = 'query_string' unless( $caller eq "${class}\::document_uri" );
         }
@@ -938,7 +858,6 @@ sub _find_path_info
     my $path = URI::file->new( $uri_path )->file( $^O );
     $doc_root = $doc_root->file( $^O ) if( Scalar::Util::blessed( $doc_root ) && $doc_root->isa( 'URI::file' ) );
     $doc_root = substr( $doc_root, 0, length( $doc_root ) - length( $sep ) ) if( substr( $doc_root, -length( $sep ), length( $sep ) ) eq $sep );
-    $self->message( 4, "Document root is '$doc_root', uri path '$uri_path' and file path is '$path'" );
     return( $self->error( "URI path must be an absolute path starting with '/'. Path provided was \"$uri_path\"." ) ) if( substr( $uri_path, 0, 1 ) ne '/' );
     ## No need to go further
     if( -e( "${doc_root}${path}" ) )
@@ -961,18 +880,15 @@ sub _find_path_info
         });
     }
     my @parts = split( '/', substr( $uri_path, 1 ) );
-    $self->message( 4, "Document root is '$doc_root' and parts contains: ", sub{ $self->dump( \@parts ) } );
     my $trypath = '';
     my $trypath_uri = '';
     my $pathinfo = '';
     foreach my $p ( @parts )
     {
-        $self->message( 4, "Checking path '${trypath_uri}/${p}'", ( $sep ne '/' ? " (${trypath}${sep}${p})" : '' ) ) unless( $pathinfo );
         ## The last path was a directory, and we cannot find the element within. So, the rest of the path is not path info, but rather a 404 missing document hierarchy
         ## We test the $pathinfo string, so we do not bother checking further if it is already set.
         if( !$pathinfo && -d( "${doc_root}${trypath}" ) && !-e( "${doc_root}${trypath}/${p}" ) )
         {
-            $self->message( 4, "Document $p is not found inside directory ${doc_root}${trypath}" );
             ## We return the original path provided (minus any query string)
             return({
                 filepath => $doc_root . ( length( $trypath ) ? $trypath :  $path ),
@@ -983,18 +899,14 @@ sub _find_path_info
         }
         elsif( !$pathinfo && -e( "${doc_root}${trypath}/${p}" ) )
         {
-            $self->message( 4, "ok, path ${trypath}/${p} exists." );
             $trypath_uri .= "/${p}";
             $trypath  .= "${sep}${p}";
         }
         else
         {
-            $self->message( 4, "nope, this path $trypath does not exist." ) if( !$pathinfo );
             $pathinfo .= "/$p";
-            $self->message( 4, "Path info is now: '$pathinfo'." );
         }
     }
-    $self->message( 4, "Real path: $trypath, path info: $pathinfo" );
     return({
         filepath => "${doc_root}${trypath}",
         path => $trypath_uri,
@@ -1038,7 +950,6 @@ sub _trim_trailing_slash
         ## By splitting the string on '/' and without the last argument for split being -1, perl will remove trailing blank entries
         $uri->path( join( '/', split( '/', $uri->path ) ) );
     }
-    $self->message( 3, "Returning uri object '", overload::StrVal( $uri ), "' with value '$uri'." );
     return( $uri );
 }
 
@@ -1115,7 +1026,7 @@ Apache2::SSI::URI - Apache2 Server Side Include URI Object Class
 
 =head1 VERSION
 
-    v0.1.1
+    v0.1.2
 
 =head1 DESCRIPTION
 
